# -*- coding: utf-8 -*-
"""
Created on Wed Nov  8 10:16:51 2021

@author: awa

This script runs delay stage scan.
This script takes Faraday cup signal instead of beam images.

"""

import os, sys

import matplotlib.pyplot as plt
import numpy as np
from win32com import client

sys.path.append("\\".join(os.getcwd().split("\\")[:-1]))
import time
from datetime import datetime

from epics import caget, caget_many, caput

timenow = datetime.now()
time_taking_data = timenow.strftime("%Y-%m-%d-%H%M")
pos_initial = -1281689  # just a reference point
info = "emission_phasescan_emissionperiodonly_124solenoid_faraday_" + time_taking_data

savedir = "E:\\AWA data\\2021\\1109\\dataScan"
ictchannel = "AWAICTMon:Ch4"
waveformchannel1 = "AWAICTMon:wf1"
waveformchannel2 = "AWAICTMon:wf2"
waveformchannel3 = "AWAICTMon:wf3"

radcam = "13ARV1:image1:ArrayData"
radcam_img_shape = (1088, 2048)  # rad hard camera resolution is 1088x2048
grabber_shape = (480, 640)  # frame grabber resolution is 480x640

delaystagepos = "WitDelay:pi:pos00"
delaystagemove = "WitDelay:pi:rel00"

# Total number of steps to move the delay stage
Nstep = 20
# The number of steps for the delay stage to move
# 5000 steps are about 1mm length
# negative means moving towards shorter path length differences
# positive means moving towards longer path length differences
delaystagestepsize = 1250
# Take 3 points per each step, wait for 1 second after taking each point
Npoints = 10

sleep_move_stage = 2
sleep_take_data = 1


pos_array = np.zeros((Nstep, Npoints))
pos_init = caget(delaystagepos)
chargedata = np.zeros((Nstep, Npoints))
waveformdata1 = np.zeros((Nstep, Npoints, 5000))
waveformdata2 = np.zeros((Nstep, Npoints, 5000))
waveformdata3 = np.zeros((Nstep, Npoints, 5000))

for eachstep in range(Nstep):
    caput(delaystagemove, delaystagestepsize)
    time.sleep(sleep_move_stage)  # wait for finishing the moving
    for eachpoint in range(Npoints):
        pos_array[eachstep, eachpoint] = caget(delaystagepos)
        # poslist.append(caget(delaystagepos))
        waveformdata1[eachstep, eachpoint, :] = caget(waveformchannel1)
        waveformdata2[eachstep, eachpoint, :] = caget(waveformchannel2)
        waveformdata3[eachstep, eachpoint, :] = caget(waveformchannel3)

        temp = caget(ictchannel)
        chargedata[eachstep, eachpoint] = temp
        print("current step: ", eachstep)
        print("current position: ", caget(delaystagepos))
        print("ICT reading: ", temp)
        time.sleep(sleep_take_data)

    print("step %d, position: %d" % (eachstep, caget(delaystagepos)))

np.save(os.path.join(savedir, info + "position.npy"), pos_array)
np.save(os.path.join(savedir, info + "ictch4data.npy"), chargedata)
np.save(os.path.join(savedir, info + "waveformch3.npy"), waveformdata3)
np.save(os.path.join(savedir, info + "waveformch2.npy"), waveformdata2)
np.save(os.path.join(savedir, info + "waveformch1.npy"), waveformdata1)
